==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-enum/xl-react-dip-enum.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import {
    computeInitialState,
    computeNextState,
    computeNextPropsState,
    getValidators
} from '../../services/component-service';

import {XlReactDipContainerProps} from '../xl-react-dip-props';
import {XlReactDipEnumComponent} from './xl-react-dip-enum-component';

export class XlReactDipEnum extends Component {
    static propTypes = {
        model: PropTypes.string,
        ...XlReactDipContainerProps
    };
    static defaultProps = {validators: []};

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        const model = getModelValue(this.props, 'model', '');
        computeInitialState(this, this.props, getValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    handleModelChange = (model, initial) => {
        computeNextState(this, this.props, getValidators(this.props), model, {pristine: initial});
    };

    api = {
        focus: () => this.childApi.focus(),
        resetPristinity: (config) => resetPristinity(this, this.props, config)
    };

    messageHandler = (message) => {
        this.setState({message});
    };

    registerChildApi = (childApi) => {
        this.childApi = childApi;
    };

    render() {
        const {metadata, onMessageChange, onPristinityChange, onValidityChange} = this.props;
        const {message, model, valid} = this.state;
        const disabled = isComponentDisabled(this.props);

        return <XlReactDipEnumComponent {...({
            disabled,
            message,
            messageHandler: this.messageHandler,
            metadata,
            model,
            onMessageChange,
            onModelChange: this.handleModelChange,
            onPristinityChange,
            onValidityChange,
            registerChildApi: this.registerChildApi,
            valid
        })}
        />;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/xl-react-dip-enum/xl-react-dip-enum.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import {
    computeInitialState,
    computeNextState,
    computeNextPropsState,
    getValidators
} from '../../services/component-service';

import {XlReactDipContainerProps} from '../xl-react-dip-props';
import {XlReactDipEnumComponent} from './xl-react-dip-enum-component';

export class XlReactDipEnum extends Component {
    static propTypes = {
        model: PropTypes.string,
        ...XlReactDipContainerProps
    };
    static defaultProps = {validators: []};

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        computeInitialState(this, this.props, getValidators(this.props), this.props.model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    handleModelChange = (model, initial) => {
        computeNextState(this, this.props, getValidators(this.props), model, {pristine: initial});
    };

    api = {
        focus: () => this.childApi.focus(),
        resetPristinity: (config) => resetPristinity(this, this.props, config)
    };

    messageHandler = (message) => {
        this.setState({message});
    };

    registerChildApi = (childApi) => {
        this.childApi = childApi;
    };

    render() {
        const {metadata, onMessageChange, onPristinityChange, onValidityChange} = this.props;
        const {message, model, valid} = this.state;
        const disabled = isComponentDisabled(this.props);

        return <XlReactDipEnumComponent {...({
            disabled,
            message,
            messageHandler: this.messageHandler,
            metadata,
            model,
            onMessageChange,
            onModelChange: this.handleModelChange,
            onPristinityChange,
            onValidityChange,
            registerChildApi: this.registerChildApi,
            valid,
            view: metadata.view
        })}
        />;
    }
}
